@@ -28,7 +28,7 @@ impl epi::App for MyApp {
                 ui.label("Your name: ");
                 ui.text_edit_singleline(name);
             });
-            ui.add(egui::Slider::u32(age, 0..=120).text("age"));
+            ui.add(egui::Slider::new(age, 0..=120).text("age"));
             if ui.button("Click each year").clicked() {
                 *age += 1;
             }
